@@ -16,7 +16,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw();
 
-our $VERSION = '0.11';
+our $VERSION = '0.14';
 
 our $errcode = 0;
 our $errmsg  = '';
@@ -158,6 +158,13 @@ sub close { my $self = shift; $self->{value} = undef;                      $self
 sub ticks { my $self = shift; return $self->{tick} }
 
 sub token {
+    my $self = shift;
+    my $tk = shift;
+    $self->{token} = ref($tk) eq 'ARRAY' ? $tk : [$tk];
+    $self->show;
+}
+
+sub tok_maybe {
     my $self = shift;
     my $tk = shift;
     $self->{token} = ref($tk) eq 'ARRAY' ? $tk : [$tk];
@@ -545,8 +552,11 @@ You can also have more than one token on a single line. Here is an example:
     };
     $ctr->close;
 
-The C<token> method is used to update the token value. If '%k' is used, then the
-counter must be instantiated with an intial value for the token.
+The C<token> method is used to update the token value immediately on the screen.
+
+The C<tok_maybe> method is used to set the token value, but the screen is not refreshed immediately.
+
+If '%k' is used, then the counter must be instantiated with an initial value for the token.
 
 =item characters '%P'
 
